
XEP-0264: Jingle Content Thumbnails
===================================

.. module:: slixmpp.plugins.xep_0264

.. autoclass:: XEP_0264
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0264.stanza
    :members:
    :undoc-members:

